==> funq-server-1.1.4.tar.gz: funq-server-1.1.4/protocole/jsonclient.h <==
/*
Copyright: SCLE SFE
Contributor: Julien Pagès <j.parkouss@gmail.com>

This software is a computer program whose purpose is to test graphical
applications written with the QT framework (http://qt.digia.com/).

This software is governed by the CeCILL v2.1 license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL v2.1 license and that you accept its terms.
*/

#ifndef JSONCLIENT_H
#define JSONCLIENT_H

#include <QObject>
#include "json.h"

class Protocole;
class QIODevice;

class JsonClient : public QObject
{
    Q_OBJECT
public:
    explicit JsonClient(QIODevice * device, QObject *parent = 0);

    ~JsonClient();
    
    QtJson::JsonObject createError(const QString & name, const QString & description);

    Protocole * protocole() { return m_protocole; }

signals:
    
private slots:
    void onMessageReceived();
private:
    Protocole * m_protocole;
};

#endif // JSONCLIENT_H

==> funq-server-1.2.0.tar.gz: funq-server-1.2.0/protocole/jsonclient.h <==
/*
Copyright: SCLE SFE
Contributor: Julien Pagès <j.parkouss@gmail.com>

This software is a computer program whose purpose is to test graphical
applications written with the QT framework (http://qt.digia.com/).

This software is governed by the CeCILL v2.1 license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL v2.1 license and that you accept its terms.
*/

#ifndef JSONCLIENT_H
#define JSONCLIENT_H

#include "json.h"

#include <QObject>

class Protocole;
class QIODevice;

class JsonClient : public QObject {
    Q_OBJECT
public:
    explicit JsonClient(QIODevice * device, QObject * parent = 0);

    ~JsonClient();

    QtJson::JsonObject createError(const QString & name,
                                   const QString & description);

    Protocole * protocole() { return m_protocole; }

signals:

private slots:
    void onMessageReceived();

private:
    Protocole * m_protocole;
};

#endif  // JSONCLIENT_H
